Module contents
---------------

.. automodule:: cellmaps_generate_hierarchy
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: cellmaps_generate_hierarchy.cellmaps_generate_hierarchycmd
   :members:
   :undoc-members:
   :show-inheritance:

Runner module
-------------------------------------------

.. autoclass:: cellmaps_generate_hierarchy.runner.CellmapsGenerateHierarchy
    :members:
    :noindex:

PPI module
-------------------------------------------

.. automodule:: cellmaps_generate_hierarchy.ppi
   :members:
   :undoc-members:
   :show-inheritance:

Hierarchy module
-------------------------------------------

.. automodule:: cellmaps_generate_hierarchy.hierarchy
   :members:
   :undoc-members:
   :show-inheritance:

Mature hierarchy module
-------------------------------------------

.. automodule:: cellmaps_generate_hierarchy.maturehierarchy
   :members:
   :undoc-members:
   :show-inheritance:


HCX (Hierarchy in CX2) module
-------------------------------------------

.. automodule:: cellmaps_generate_hierarchy.hcx
   :members:
   :undoc-members:
   :show-inheritance:

Layout module
-------------------------------------------

.. automodule:: cellmaps_generate_hierarchy.layout
   :members:
   :undoc-members:
   :show-inheritance:

NDEx Upload module
-------------------------------------------

.. automodule:: cellmaps_generate_hierarchy.ndexupload
   :members:
   :undoc-members:
   :show-inheritance:

Exceptions
-------------------------------------------

.. automodule:: cellmaps_generate_hierarchy.exceptions
   :members:
   :undoc-members:
   :show-inheritance:

